package com.gic.auth.service.outer.impl;

import com.gic.auth.entity.TabSysAccountGroup;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.error.ErrorCode;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.AccountGroupDTO;
import com.gic.auth.service.AccountGroupApiService;
import com.gic.auth.service.AccountGroupService;
import com.gic.enterprise.utils.valid.ValidParamsUtils;

import java.util.ArrayList;
import java.util.List;

@Service("AccountGroupApiService")
public class AccountGroupApiServiceImpl implements AccountGroupApiService{
    @Autowired
    private AccountGroupService accountGroupService;
    @Override
    public ServiceResponse<Integer> save(AccountGroupDTO dto) {
        ServiceResponse paramValid = ValidParamsUtils.allCheckValidate(AccountGroupDTO.class, AccountGroupDTO.SaveValid.class);
        if (!paramValid.isSuccess()) {
            return paramValid;
        }
        if (accountGroupService.isAccountGroupNameRepeat(dto.getEnterpriseId(), null, dto.getAccountGroupName())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "账号分组名称不能重复");
        }
        //sort值设置
        int maxSortValue = accountGroupService.getMaxSortValueByEnterpriseId(dto.getEnterpriseId());
        dto.setSort(maxSortValue + 1);
        return ServiceResponse.success(accountGroupService.save(dto));
    }

    @Override
    public ServiceResponse<Integer> update(AccountGroupDTO dto) {
        TabSysAccountGroup record = accountGroupService.getById(dto.getAccountGroupId());
        if (record == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "账号分组id有误，查无数据");
        }
        ServiceResponse paramValid = ValidParamsUtils.allCheckValidate(AccountGroupDTO.class, AccountGroupDTO.EditValid.class);
        if (!paramValid.isSuccess()) {
            return paramValid;
        }
        if (accountGroupService.isAccountGroupNameRepeat(dto.getEnterpriseId(), dto.getAccountGroupId(), dto.getAccountGroupName())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "账号分组名称不能重复");
        }
        dto.setEnterpriseId(record.getEnterpriseId());
        dto.setSort(record.getSort());

        return ServiceResponse.success(accountGroupService.update(dto));
    }

    @Override
    public ServiceResponse<List<AccountGroupDTO>> listAccountGroupByEnterpriseId(Integer enterpriseId) {
        List<TabSysAccountGroup> list = accountGroupService.listAccountGroupByEnterpriseId(enterpriseId);
        if (CollectionUtils.isNotEmpty(list)) {
            return ServiceResponse.success(EntityUtil.changeEntityListNew(AccountGroupDTO.class, list));
        }
        return ServiceResponse.success(new ArrayList<>());
    }

    @Override
    public ServiceResponse<Void> deleteByAccountGroupId(Integer accountGroupId) {
        TabSysAccountGroup record = accountGroupService.getById(accountGroupId);
        if (record == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "账号分组id有误，查无数据");
        }
        //逻辑删除分组
        accountGroupService.updateStatusByAccountGroupId(accountGroupId);
        //todo 删除组员分组关系数据

        return ServiceResponse.success();
    }
}
